<?php

class T2a_Age_Verify_AdminPages{

    public $plugin_name;
    public $menu;
    
    function __construct($plugin_name , $version){
        $this->plugin_name    = $plugin_name;
        $this->version        = $version;
        $this->key            = get_option('t2a_age_verify_api_key');
        $this->full_site      = get_option('t2a_age_verify_full_site');
        $this->sandbox_env    = get_option('t2a_age_verify_sandbox_env');
        $this->product_verify = get_option('t2a_age_verify_product_verify');
        $this->user_array     = unserialize(get_option('t2a_age_verify_user_array')) ? unserialize(get_option('t2a_age_verify_user_array')) : array();
        $this->verify_array   = unserialize(get_option('t2a_age_verify_verify_array')) ? unserialize(get_option('t2a_age_verify_verify_array')) : array();

        if($this->sandbox_env == "true") {
            $this->active_key = "sandbox";
        }
        else {
            $this->active_key = $this->key;
        }

        if($this->key) {
            $this->credit_balance = $this->get_credit_balance();
        }
        else {
            $this->credit_balance = "no_key";
        }

        if($this->key && $this->credit_balance != "invalid_key")
        {
            add_action( 'admin_menu', array($this,'admin_menu') );
        }
        else {
            add_action( 'admin_menu', array($this,'admin_menu_no_key') );
        }

    }

    function admin_menu(){
         add_menu_page(
            __( 'T2A Age Verify'),
            __( 'T2A Age Verify'),
            'manage_options',
            't2a-age-verify',
            array($this, 'settings_page'),
            plugin_dir_url( __FILE__ ).'img/t2a.png',
            6
        );

        add_submenu_page('t2a-age-verify', 'T2A Age Verify Settings', 'Settings', 'manage_options', 't2a-age-verify', array($this, 'settings_page') );
        add_submenu_page('t2a-age-verify', 'T2A Age Verify Users', 'Customers', 'manage_options', 't2a-age-verify-users', array($this, 'user_page'));
        add_submenu_page('t2a-age-verify', 'T2A Age Verify Demo', 'Demo', 'manage_options', 't2a-age-verify-demo', array($this, 'demo_page'));
        add_submenu_page('t2a-age-verify', 'T2A Age Verify Advanced', 'Advanced', 'manage_options', 't2a-age-verify-advanced', array($this, 'advanced_page'));

    }

    function admin_menu_no_key() {
        add_menu_page(
            __( 'T2A Age Verify'),
            __( 'T2A Age Verify'),
            'manage_options',
            't2a-age-verify',
            array($this, 'settings_page'),
            plugin_dir_url( __FILE__ ).'img/t2a.png',
            6
        );
    }

    public function bootstrap_style() {
        wp_enqueue_style( $this->plugin_name."_bootstrap", plugin_dir_url( __FILE__ ) . 'css/bootstrap.css', array(), $this->version, 'all' );
	}

    function settings_page(){
        if(isset($_POST['form_submitted'])) {
            if(isset($_POST['apikey'])) {
                $this->key = $_POST['apikey'];
            }else {
                $this->key = "";
            }

            if(isset($_POST['full_site'])) {
                $this->full_site = "true";
            }else {
                $this->full_site = "";
            }

            if(isset($_POST['product_verify'])) {
                $this->product_verify = "true";
            } else {
                $this->product_verify = "";
            }

            if(isset($_POST['products'])) {
                $this->verify_array = $_POST['products'];
                update_option('t2a_age_verify_verify_array', serialize($this->verify_array));
            }

            update_option('t2a_age_verify_product_verify', $this->product_verify);
            update_option('t2a_age_verify_api_key', $this->key);
            update_option('t2a_age_verify_full_site', $this->full_site);
        }

        if($this->key) {
            $this->credit_balance = $this->get_credit_balance();
            if($this->credit_balance != "invalid_key") {
                if($this->credit_balance < 10) {
                    add_action('admin_notices', array($this, 'no_credit_notice'));
                    do_action('admin_notices');
                }
                else if($this->credit_balance <= 1000) {
                    add_action('admin_notices', array($this, 'low_credit_notice'));
                    do_action('admin_notices');
                }
                echo $this->page_with_key();
            }
            else {
                add_action('admin_notices', array($this, 'invalid_key_notice'));
                do_action('admin_notices');

                echo $this->page_no_key();
            }
        }
        else {
            $this->credit_balance = "no_key";
            $this->page_no_key();
        }

    }

    function user_page() {
        if(isset($_POST["run_verification"])) {
            $surname = isset($_POST["last_name"])?$_POST["last_name"]:"";
            $forename = isset($_POST["first_name"])?$_POST["first_name"]:"";
            $addr1 = isset($_POST["address_1"])?$_POST["address_1"]:"";
            $postcode = isset($_POST["postcode"])?$_POST["postcode"]:"";
            $username = isset($_POST["username"])?$_POST["username"]:"";
            $this->run_verification($surname, $forename, $addr1, $postcode, $username);
        }
        if(isset($_POST["manual_verification"])) {
            $username = isset($_POST["username"])?$_POST["username"]:"";
            $this->user_array[$username] = "true";
            update_option('t2a_age_verify_user_array', serialize($this->user_array));
        }
        if(isset($_POST["unverify"])) {
            $username = isset($_POST["username"])?$_POST["username"]:"";
            unset($this->user_array[$username]);
            update_option('t2a_age_verify_user_array', serialize($this->user_array));
        }

        require_once plugin_dir_path(__FILE__) . 'templates/users.php';
    }

    function demo_page() {
        wp_enqueue_style( $this->plugin_name . "_demo", plugin_dir_url( __FILE__ ) . 'css/t2a-age-verify-demo.css', array(), $this->version, 'all' );
        wp_enqueue_script( $this->plugin_name . "_demo", plugin_dir_url( __FILE__ ) . 'js/t2a-age-verify-demo.js', array( 'jquery' ), $this->version, false );
        require_once plugin_dir_path(__FILE__) . 'templates/demo.php';
    }

    function advanced_page() {
        if(isset($_POST['form_submitted'])) {

            if (isset($_POST['sandbox_env'])) {
                $this->sandbox_env = "true";
            } else {
                $this->sandbox_env = "";
            }

            update_option('t2a_age_verify_sandbox_env', $this->sandbox_env);
        }

        require_once plugin_dir_path(__FILE__) . 'templates/advanced.php';
    }

    function page_with_key() {
        require_once plugin_dir_path(__FILE__) . 'templates/admin.php';
    }

    function page_no_key() {
        wp_enqueue_style( $this->plugin_name . "_demo", plugin_dir_url( __FILE__ ) . 'css/t2a-age-verify-demo.css', array(), $this->version, 'all' );
        wp_enqueue_script( $this->plugin_name . "_demo", plugin_dir_url( __FILE__ ) . 'js/t2a-age-verify-demo.js', array( 'jquery' ), $this->version, false );
        require_once plugin_dir_path(__FILE__) . 'templates/nokey.php';
    }


    protected function get_cur_url() {
        $protocol = ((!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off') || $_SERVER['SERVER_PORT'] == 443) ? "https://" : "http://";
        $CurPageURL = $protocol . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
        return $CurPageURL;
    }

    protected function run_verification($surname, $forename, $addr1, $postcode, $username) {
        $params = [
            "api_key"  => $this->active_key,
            "method"   => "age_verification",
            "surname"  => $surname,
            "forename" => $forename,
            "addr1"    => $addr1,
            "postcode" => $postcode,
            "output"   => "json"
        ];

        $query = http_build_query($params);

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL,"https://api.t2a.io/rest/");
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $query);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

        $response = curl_exec($ch);
        curl_close ($ch);

        $resObj = json_decode($response);

        if($resObj->validation_status == "FOUND"){
            $this->user_array[$username] = "true";
        }


        update_option('t2a_age_verify_user_array', serialize($this->user_array));
    }

    protected function get_credit_balance() {
        $params = [
            "api_key"  => $this->key,
            "method"   => "client_info",
            "output"   => "json"
        ];

        $query = http_build_query($params);

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL,"https://api.t2a.io/rest/");
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $query);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

        $response = curl_exec($ch);
        curl_close ($ch);

        $resObj = json_decode($response);


        if($resObj->error_code == "invalid_api_key" || $resObj->error_code == "missing_api_key") {
            return "invalid_key";
        }
        else {
            return (int)$resObj->credit_balance;
        }
    }

    public function low_credit_notice() {
        ?>
        <div class="update-nag notice">
            <p><?php _e( 'You are running low on credits. To continue to use the age verification service uninterrupted please <a href="https://t2a.io/pricing" target="_blank">buy credits</a>', 't2a_age_verify' ); ?></p>
        </div>
        <?php
    }

    public function invalid_key_notice() {
        ?>
        <div class="error notice">
            <p><?php _e( 'Invalid API key', 't2a_age_verify' ); ?></p>
        </div>
        <?php
    }
    public function no_credit_notice() {
        ?>
        <div class="error notice">
            <p><?php _e( 'You do not have enough credits to verify customers. Age Verification is now switched off until you purchase more credits', 't2a_age_verify' ); ?></p>
        </div>
        <?php
    }

    public function run_verification_pass() {
        ?>
        <div class="update notice">
            <p><?php _e( 'User successfully verified', 't2a_age_verify' ); ?></p>
        </div>
        <?php
    }

    public function run_verification_fail() {
        ?>
        <div class="error notice">
            <p><?php _e( 'Could not verify user', 't2a_age_verify' ); ?></p>
        </div>
        <?php
    }

    public function manual_verification() {
        ?>
        <div class="update notice">
            <p><?php _e( 'User manually verified', 't2a_age_verify' ); ?></p>
        </div>
        <?php
    }


}