<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       piwebsolution.com
 * @since      1.0.0
 *
 * @package    T2a_Age_Verify
 * @subpackage T2a_Age_Verify/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    T2a_Age_Verify
 * @subpackage T2a_Age_Verify/public
 * @author     PI Websolution <sales@piwebsolution.com>
 */
class T2a_Age_Verify_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
    public function __construct( $plugin_name, $version ) {

        $this->plugin_name    = $plugin_name;
        $this->version        = $version;
        $this->key            = get_option('t2a_age_verify_api_key');
        $this->verify_array   = unserialize(get_option('t2a_age_verify_verify_array')) ? unserialize(get_option('t2a_age_verify_verify_array')) : array();
        $this->product_verify = get_option('t2a_age_verify_product_verify');
        $this->full_site      = get_option('t2a_age_verify_full_site');
        $this->credit_balance = $this->get_credit_balance();
        $this->sandbox_env    = get_option('t2a_age_verify_sandbox_env');

        if($this->sandbox_env == "true") {
            $this->active_key = "sandbox";
        }
        else {
            $this->active_key = $this->key;
        }

        if(($this->product_verify || $this->full_site)) {
            if(($this->credit_balance > 0 && $this->credit_balance != "invalid_key") || $this->sandbox_env == "true")
            add_action( 'woocommerce_after_checkout_validation', array( $this, 'age_verify_checkout'));
        }

    }

    public function age_verify_checkout() {

        if($this->full_site) {
            $validation = true;
        }
        else {
            foreach ( WC()->cart->get_cart() as $cart_item ) {
                if(in_array($cart_item['data']->get_id(), $this->verify_array)){
                    $validation = true;
                }
            }
        }

        if(is_user_logged_in()) {
            $user = wp_get_current_user();
            if($this->user_array[$user->display_name]) {
                $validation = false;
            }
        }



        if($validation) {
            $params = [
                "api_key"  => $this->active_key,
                "method"   => "age_verification",
                "surname"  => $_POST["billing_last_name"],
                "forename" => $_POST['billing_first_name'],
                "addr1"    => $_POST['billing_address_1'],
                "postcode" => $_POST['billing_postcode'],
                "output"   => "json"
            ];

            $query = http_build_query($params);

            echo $query;

            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL,"https://api.t2a.io/rest/");
            curl_setopt($ch, CURLOPT_POST, 1);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $query);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

            $response = curl_exec($ch);
            curl_close ($ch);

            $resArray = json_decode($response);

            if($resArray->validation_status != "FOUND"){
                wc_add_notice( __("Your basket contains age-restricted item(s) for which we were unable to verify your age as 18 or over.", 'woocommerce' ), 'error' );
            } else if(is_user_logged_in()) {
                $user = wp_get_current_user();
                $this->user_array[$user->display_name] = true;
                update_option('t2a_age_verify_user_array', serialize($this->user_array));
            }
        }
    }

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in T2a_Age_Verify_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The T2a_Age_Verify_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		//wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/extended-flat-rate-shipping-woocommerce-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in T2a_Age_Verify_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The T2a_Age_Verify_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		//wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/t2a-age-verify-checkout.js', array( 'jquery' ), $this->version, false );

	}

    protected function get_credit_balance() {
        $params = [
            "api_key"  => $this->key,
            "method"   => "client_info",
            "output"   => "json"
        ];

        $query = http_build_query($params);

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL,"https://api.t2a.io/rest/");
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $query);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

        $response = curl_exec($ch);
        curl_close ($ch);

        $resObj = json_decode($response);

        if($resObj->error_code == "invalid_api_key" || $resObj->error_code == "missing_api_key") {
            return "invalid_key";
        }
        else {
            return (int)$resObj->credit_balance;
        }
    }

}
