<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              t2a.io
 * @since             1.0.0
 * @package           T2a_Age_Verify
 *
 * @wordpress-plugin
 * Plugin Name:       T2A Age Verify
 * Plugin URI:        t2a.io
 * Description:       Verify the age of your UK customers at point of registration, point of sale and in bulk. Age restrict your products or your entire shop.
 * Version:           1.0.0
 * Author:            T2A
 * Author URI:        t2a.io
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 */

// Check wordpress instance running
if ( ! defined( 'WPINC' ) ) {
	die;
}

include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

// Check WooCommerce instance running
if(!is_plugin_active( 'woocommerce/woocommerce.php')){
    function no_woo_note() {
        ?>
        <div class="error notice">
            <p><?php echo( 'Please install and activate WooCommerce plugin, without that the T2A Age Verify plugin will not work' ); ?></p>
        </div>
        <?php
    }
    add_action( 'admin_notices', 'no_woo_note' );
    deactivate_plugins(plugin_basename(__FILE__));
    return;
}



/**
 * Current plugin version.
 */
define( 'T2A_AGE_VERIFY_VERSION', '1.0.0' );
define('T2A_REG_URL', 'https://t2a.io/application_request');;


/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-t2a-age-verify-activator.php
 */
function activate_t2a_age_verify() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-t2a-age-verify-activator.php';
	T2a_Age_Verify_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-t2a-age-verify-deactivator.php
 */
function deactivate_t2a_age_verify() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-t2a-age-verify-deactivator.php';
	T2a_Age_Verify_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_t2a_age_verify' );
register_deactivation_hook( __FILE__, 'deactivate_t2a_age_verify' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-t2a-age-verify.php';

function tav_plugin_link( $links ) {
	$links = array_merge( array(
        '<a href="' . esc_url( admin_url( '/admin.php?page=tav-notification' ) ) . '">' . __( 'Settings' ) . '</a>',
        '<a style="color:#0a9a3e; font-weight:bold;" target="_blank" href="https://t2a.io/">' . __( 'Get an API key' ) . '</a>'
	), $links );
	return $links;
}
add_action( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'tav_plugin_link' );


/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.2.9
 */
function run_t2a_age_verify() {

	$plugin = new T2a_Age_Verify();
	$plugin->run();

}
run_t2a_age_verify();